Conversation API
================

.. currentmodule:: datamaestro_text.data.conversation

Data classes
------------

.. autoclass:: Entry
    :members:

.. autoclass:: DecontextualizedDictEntry
    :members:

.. autoclass:: AnswerEntry
    :members:

.. autoclass:: RetrievedEntry
    :members:

.. autoclass:: ClarifyingQuestionEntry
    :members:


.. autoclass:: Conversation

.. autoclass:: ConversationTopic

Contextual query reformulation
------------------------------

.. autoclass:: ContextualizedRewrittenQuery
    :members:

.. autoxpmconfig:: datamaestro_text.data.conversation.canard.CanardDataset
    :members: iter

.. autoclass:: OrConvQADatasetAnswer
    :members:

.. autoclass:: OrConvQADatasetHistoryEntry
    :members:

.. autoclass:: OrConvQADataset
    :members:

.. autoxpmconfig:: OrConvQADataset
    :members: iter
